from enum import Enum


class TestProjectFiles(Enum):
    CONFIGS_DIR = "configs"
    CONFIG_FILE = "config.py"
    PAGE_OBJECT_DIR = "page_object"
    PAGES_DIR = "pages"
    POPUPS_DIR = "popups"
    BASE_PAGE = "base_page.py"
    BASE_POPUP = "base_popup.py"
    SERVICES_DIR = "services"
    BASE_SERVICE = "base_service.py"
    TESTS_DIR = "tests"
    BASE_TEST = "base_test.py"
    TOOLS_FOLDER = "tools"
    UTILS_FOLDER = "utils"
